/**
 * WSP (Windows Search Provider)
 * extension.js
 *
 * @author     GdH <G-dH@github.com>
 * @copyright  2024
 * @license    GPL-3.0
 *
 */

'use strict';

const ExtensionUtils = imports.misc.extensionUtils;
const MyExtension = ExtensionUtils.getCurrentExtension();
const WindowsSearchProviderModule = MyExtension.imports.windowsSearchProvider.WindowsSearchProviderModule;
const Settings = MyExtension.imports.settings;
const Util = MyExtension.imports.util;

function init() {
    ExtensionUtils.initTranslations();
    return new ESP();
}

class ESP {
    enable() {
        const Me = MyExtension;
        Me.providerId = 'open-windows';
        // prefix helps to eliminate results from other search providers
        // this prefix is also used by the V-Shell to activate this provider
        Me.defaultPrefix = 'wq//';

        // Me.getSettings = ExtensionUtils.getSettings;
        Me.metadata = MyExtension.metadata;
        Me.gSettings = ExtensionUtils.getSettings(Me.metadata['settings-schema']);
        Me.Settings = Settings;
        Me.Util = Util;
        Me._ = imports.gettext.domain(Me.metadata['gettext-domain']).gettext;
        Me.opt = new Me.Settings.Options(Me);

        this._wsp = new WindowsSearchProviderModule(Me);
        this._wsp.update();

        this.Me = Me;
    }

    disable() {
        this._wsp.update(true);
        this._wsp.cleanGlobals();
        this.Me.opt.destroy();
        this.Me.opt = null;
        this.Me.Util.cleanGlobals();
        this.Me = null;
        this._wsp = null;
    }
}
